@@ -1,8 +1,8 @@
 /*
- *  SPDX-FileCopyrightText: 2013 Andreas Cord-Landwehr <cordlandwehr@kde.org>
- *
- *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
- */
+    SPDX-FileCopyrightText: 2013 Andreas Cord-Landwehr <cordlandwehr@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #ifndef PHONEMEGROUP_H
 #define PHONEMEGROUP_H
@@ -49,7 +49,6 @@ Q_SIGNALS:
     void idChanged();
     void titleChanged();
     void descriptionChanged();
-    void phonemeAdded(const Phoneme &);
 
 private:
     Q_DISABLE_COPY(PhonemeGroup)
